@@ -147,7 +147,7 @@ class Crp:
         target = train_df[train_df.customerid.map(matrix['order_date']) == train_df.order_date][['customerid','totalprice']]
         matrix = matrix.reset_index()
         output = pd.merge(target,matrix,on='customerid')
-        output.drop_duplicates(inplace = True)
+        # output.drop_duplicates(inplace = True)
         
         # Output
         return output
@@ -171,6 +171,9 @@ class Crp:
         
         last_month_spent = last_month_df.groupby('customerid').agg({'totalprice':'sum'}).reset_index()
         
+
+        df_matrix = df_matrix.reset_index()
+
         df_matrix = pd.merge(df_matrix,last_month_spent,on='customerid',how = 'left')
         
         
